//#####
//###  Epoz - a cross-browser-wysiwyg-editor for Zope
//##   Copyright (C) 2003 Maik Jablonski (maik.jablonski@uni-bielefeld.de)
//#

// Just to prevent typos when fetching the Epoz-IFrame...

var Epoz = "EpozEditor";

// Adjust this if you encounter problems with Mozilla / Netscape

var EpozTimeOut = 250;

// Speed-Up-Storage for document.getElementById(Epoz);

var EpozElement;
var EpozTextArea;

// Global storages

var form_data;  // the document-data
var form_name;  // the name of the form-element
var form_path;  // path to buttons, font-selectors, ...
var form_toolbox; // path to optional toolbox
var form_area_style; // css-definition for wysiwyg-area
var form_button_style; // css-definition for buttons

// Detect browser type and create Epoz- or Default-Textbox

function InitEpoz(name, data, path, toolbox, style, button) {

    form_name = name;
    form_data = data; 
    form_path = path;
    form_toolbox = toolbox;
    form_area_style = style;
    form_button_style = button;
        
    if (browser.isIE5up) {
        // Mac-IE doesn't support RichText-Edit at the moment
        if (browser.isMac) {
            CreateTextarea();
        } else {
            CreateEpoz();
        }
    }
    else if (browser.isGecko) {
        //check to see if midas is enabled
        try {
            document.getElementById('EpozIFrame').contentDocument.designMode = "on";
            document.getElementById('EpozIFrame').contentWindow.document.execCommand("undo", false, null);
            CreateEpoz();
        } catch (e) {
            CreateTextarea();
        }
    }
    else {
        CreateTextarea();
    }
}


// Needs to be called by timeout for Mozilla... Mozilla is a slow dragon...

function EnableDesignMode() {

    if (browser.isIE5up) {
        frames[Epoz].document.designMode = "On";
    }
    else {
        EpozElement.contentDocument.designMode = "on";
    }
	
    // Set all forms in sync with Epoz
    
    if (document.getElementsByTagName)
        var x = document.getElementsByTagName('FORM');
    else if (document.all)
        var x = document.all.tags('FORM');

    for (var i=0;i<x.length;i++) {
        x[i].onsubmit = SyncEpoz;
    }
}


// A submit-wrapper to pass the parameters into the form-element

function SyncEpoz() {

	// Just a simple workaround...
	// Switching views results in code,
	// that is slightly (x)html-cleaned
	// automatically by the browser.
		
	if (document.getElementById('EpozViewMode').checked) {
        SwitchViewMode(0);
        SwitchViewMode(1);
        html = document.getElementById(form_name).value;
    } else {
        SwitchViewMode(1);
        html = document.getElementById(form_name).value;
	}

  	document.getElementById(form_name).value = TidyHTML(html);
}

// Convert all IE-format-tags to Mozilla-format-tags
// IE is much smarter when editing the Mozilla-format-tags

function TidyHTML(html) {

        html = html.replace(/<strong>/ig,'<b>');
        html = html.replace(/<\/strong>/ig,'</b>');

        html = html.replace(/<em>/ig,'<i>');
        html = html.replace(/<\/em>/ig,'</i>');

		return html;
}

// -------------------------------------------------------------
// Here are the definitions for the control-and-format-functions

// Intialize the document

function InitDocument() {
    // Store the Editor-Element in a global variable    
    EpozElement = document.getElementById(Epoz);
    EpozTextArea = document.getElementById(form_name);
    
    // Put data into Epoz-Editor
    EpozElement.contentWindow.document.body.innerHTML = form_data; 
}


// Format text with RichText-Controls

function FormatText(command, option) {
    EpozElement.contentWindow.focus();
    
    // Mozilla inserts css-styles per default
    
	if (browser.isGecko) {
    	EpozElement.contentWindow.document.execCommand('useCSS',false, true);
    }
    
    EpozElement.contentWindow.document.execCommand(command, false, option);
}


// Insert arbitrary HTML at current selection

function InsertHTML(html) {

    EpozElement.contentWindow.focus();

    if (browser.isIE5up) {
        selection = EpozElement.contentWindow.document.selection;
        range = selection.createRange();
        try {
            range.pasteHTML(html);        
        } catch (e) {
            // catch error when range is evil for IE        
        }
    } else {
        selection = EpozElement.contentWindow.window.getSelection();
        EpozElement.contentWindow.focus();
        if (selection) {
            range = selection.getRangeAt(0);
        } else {
            range = EpozElement.contentWindow.document.createRange();
        } 

        var fragment = EpozElement.contentWindow.document.createDocumentFragment();
        var div = EpozElement.contentWindow.document.createElement("div");
        div.innerHTML = html;

        while (div.firstChild) {
            fragment.appendChild(div.firstChild);
        }

        selection.removeAllRanges();
        range.deleteContents();

        var node = range.startContainer;
        var pos = range.startOffset;

        switch (node.nodeType) {
            case 3:
                if (fragment.nodeType == 3) {
                    node.insertData(pos, fragment.data);
                    range.setEnd(node, pos + fragment.length);
                    range.setStart(node, pos + fragment.length);
                } else {
                    node = node.splitText(pos);
                    node.parentNode.insertBefore(fragment, node);
                    range.setEnd(node, pos + fragment.length);
                    range.setStart(node, pos + fragment.length);
                }
                break;

            case 1:
                node = node.childNodes[pos];
                node.parentNode.insertBefore(fragment, node);
                range.setEnd(node, pos + fragment.length);
                range.setStart(node, pos + fragment.length);
                break;
        }
        selection.addRange(range);
    }
}


// Create a Hyperlink - IE has its own implementation

function CreateLink(URL) {
    if (browser.isIE5up == false && ((URL == null) || (URL == ""))) {
        URL = prompt(EpozLang["EnterLinkURL"], "");

        if ((URL != null) && (URL != "")) {
            EpozElement.contentWindow.document.execCommand("CreateLink",false,URL)
        } else {
            EpozElement.contentWindow.document.execCommand("Unlink",false, "")
        }
    } else {
        EpozElement.contentWindow.document.execCommand("CreateLink",false,URL)
    }
}


// Insert image via a URL

function CreateImage(URL) {
    if ((URL == null) || (URL == "")) {
        URL = prompt(EpozLang["EnterImageURL"], "");
    }
    if ((URL != null) && (URL != "")) {
        EpozElement.contentWindow.focus()
        EpozElement.contentWindow.document.execCommand('InsertImage', false, URL);
    }
}


// Creates a simple table

function CreateTable(rows, cols, border) {
    rows = parseInt(rows);
    cols = parseInt(cols);

    if ((rows > 0) && (cols > 0)) {
       table = ' <table border="' + border + '">\n';

       for (var i=0; i < rows; i++) {
          table = table + " <tr>\n";
          for (var j=0; j < cols; j++) {
             table += "  <td>#</td>\n";
          }
          table += " </tr>\n";
       }
       table += " </table>\n";
       InsertHTML(table);
    }
    EpozElement.contentWindow.focus()
}


// Sets selected formats

function SelectFormat(selectname)
{
    // First one is only a label
    if (selectname.selectedIndex != 0) {
        EpozElement.contentWindow.document.execCommand(selectname.id, false, selectname.options[selectname.selectedIndex].value);
        selectname.selectedIndex = 0;
    }
    EpozElement.contentWindow.focus();
}


// Sets foreground-color

function SetTextColor() {
    EpozColorCommand='forecolor';
    window.open(form_path+'epoz_script_color.html','EpozColor','toolbar=no,location=no,status=no,menubar=no,scrollbars=yes,resizable=yes,width=220,height=220');
}    

// Sets background-color

function SetBackColor() {
    EpozColorCommand='backcolor';
    window.open(form_path+'epoz_script_color.html','EpozColor','toolbar=no,location=no,status=no,menubar=no,scrollbars=yes,resizable=yes,width=220,height=220');
}    

// Submit color-command to Rich-Text-Controls

function SetColor(color) {

    if (browser.isGecko) {
       EpozElement.contentWindow.document.execCommand('useCSS',false, false);
    }
    
    EpozElement.contentWindow.document.execCommand(EpozColorCommand, false, color);
    EpozElement.contentWindow.focus();
}

// Switch between Source- and Wysiwyg-View

function SwitchViewMode(mode)
{
	if (mode) {

		try {
			html = EpozElement.contentWindow.document.body.innerHTML;
		} catch (e) {
			html = EpozElement.value;
		}

		document.getElementById("EpozToolbar").style.display="none";
		EpozTextArea.value=html;
		EpozTextArea.style.display="inline";

	} else {

		html = EpozTextArea.value;  
		EpozElement.contentWindow.document.body.innerHTML = html; 
		document.getElementById("EpozToolbar").style.display="inline";
		EpozTextArea.style.display="none";
   
   		if (browser.isGecko) {
			EpozElement.contentDocument.designMode = "on"; 
		}
  }
}
